@@ -235,8 +235,12 @@ def fn_get_many(models, model_type):
                     except Exception as e:
                         debug(f"Failed to coerce type while processing filters; {e}. ")
                     valid = evaluate_condition(condition, model_value, value)
-                    if valid:
-                        to_return.append(model)
+                    if not valid:
+                        break
+                else:
+                    # for else: https://book.pythontips.com/en/latest/for_-_else.html
+                    # only runs if there were no breaks (so no filters were invalid)
+                    to_return.append(model)
         if "join" in kwargs:
             self.resolve_joins(to_return, kwargs["join"])
         return_type = models[f"GetMany{model_type.__name__}ResponseDto"]
