@@ -251,4 +251,4 @@ class _Model(ABC):
             self.model_id,
             self._job_type,
         )
-        return self.session.api_instance.model_job_controller_status(self.model_id, self._job_type)
+        return self.session.api_instance.get_one_base_model_controller_model(self.model_id, self._job_type)
