@@ -1,4 +1,4 @@
-from curia.api.swagger_client import Dataset, DatasetJob
+from curia.api.swagger_client import Dataset
 from curia.session import Session
 from curia.utils.s3 import s3_listdir, get_metadata
 
@@ -32,9 +32,4 @@ def create_dataset_from_s3_path(
         )
     )
 
-    dataset_job = session.api_instance.create_one_base_dataset_job_controller_dataset_job(
-        DatasetJob(
-            dataset_id=dataset.id
-        )
-    )
-    return dataset, dataset_job
+    return dataset
