@@ -1,6 +1,17 @@
 import re
 
 
+def first_lower(s):
+    """
+    Convert first letter of a string to lowercase
+    :param s: String to make Lowercase
+    :return: String with first letter lowercase
+    """
+    if len(s) == 0:
+        return s
+    return s[0].lower() + s[1:]
+
+
 def to_camel_case(snake_str):
     """
     Convert snake_case to UpperCamelCase
@@ -12,6 +23,15 @@ def to_camel_case(snake_str):
     return ''.join(x.title() for x in snake_str.split('_'))
 
 
+def to_lower_camel_case(snake_str):
+    """
+    Convert snake_case to lowerCamelCase
+    :param snake_str:
+    :return: string in lower camel case
+    """
+    return first_lower(to_camel_case(snake_str))
+
+
 # see https://stackoverflow.com/questions/1175208/elegant-python-function-to-convert-camelcase-to-snake-case
 to_snake_case_pattern = re.compile(r'(?<!^)(?=[A-Z])')
 
@@ -22,4 +42,4 @@ def to_snake_case(camel_str):
     :param camel_str:
     :return: string in snake case
     """
-    return to_snake_case_pattern.sub('_', camel_str).lower()
\ No newline at end of file
+    return to_snake_case_pattern.sub('_', camel_str).lower()
